@@ -22,12 +22,12 @@ from ask_sdk_model.interfaces.amazonpay.model.v1.billing_agreement_details impor
 
 
 if typing.TYPE_CHECKING:
-    from typing import Dict, List, Optional, Union
+    from typing import Dict, List, Optional, Union, Any
     from datetime import datetime
-    from ask_sdk_model.interfaces.amazonpay.model.v1.billing_agreement_status import BillingAgreementStatusV1
-    from ask_sdk_model.interfaces.amazonpay.model.v1.destination import DestinationV1
-    from ask_sdk_model.interfaces.amazonpay.model.response.destination import Destination
-    from ask_sdk_model.interfaces.amazonpay.model.response.release_environment import ReleaseEnvironment
+    from ask_sdk_model.interfaces.amazonpay.model.v1.billing_agreement_status import BillingAgreementStatus as BillingAgreementStatus_92faa5c4
+    from ask_sdk_model.interfaces.amazonpay.model.response.release_environment import ReleaseEnvironment as ReleaseEnvironment_a12fed99
+    from ask_sdk_model.interfaces.amazonpay.model.response.destination import Destination as Destination_c290e254
+    from ask_sdk_model.interfaces.amazonpay.model.v1.destination import Destination as Destination_1fa740ce
 
 
 class BillingAgreementDetails(BillingAgreementDetails):
@@ -73,7 +73,7 @@ class BillingAgreementDetails(BillingAgreementDetails):
     supports_multiple_types = False
 
     def __init__(self, billing_agreement_id=None, creation_timestamp=None, destination=None, checkout_language=None, release_environment=None, billing_agreement_status=None, billing_address=None):
-        # type: (Optional[str], Optional[datetime], Optional[DestinationV1], Optional[str], Optional[ReleaseEnvironment], Optional[BillingAgreementStatusV1], Optional[Destination]) -> None
+        # type: (Optional[str], Optional[datetime], Optional[Destination_1fa740ce], Optional[str], Optional[ReleaseEnvironment_a12fed99], Optional[BillingAgreementStatus_92faa5c4], Optional[Destination_c290e254]) -> None
         """The result attributes from successful SetupAmazonPay call.
 
         :param billing_agreement_id: Billing agreement id which can be used for one time and recurring purchases
